@@ -1,6 +1,6 @@
 """
 ****************************************************************************************************
-:copyright (c) 2019-2021 URBANopt, Alliance for Sustainable Energy, LLC, and other contributors.
+:copyright (c) 2019-2022, Alliance for Sustainable Energy, LLC, and other contributors.
 
 All rights reserved.
 
@@ -43,12 +43,14 @@ from os import fdopen, remove
 from shutil import copymode, move
 from tempfile import mkstemp
 
+import numpy as np
 from geojson_modelica_translator.model_connectors.load_connectors.load_base import (
     LoadBase
 )
 from geojson_modelica_translator.modelica.input_parser import PackageParser
 from geojson_modelica_translator.utils import (
     ModelicaPath,
+    convert_c_to_k,
     copytree,
     simple_uuid
 )
@@ -124,7 +126,7 @@ class Teaser(LoadBase):
             prj.add_non_residential(
                 method="bmvbs",
                 usage=self.lookup_building_type(self.building["building_type"]),
-                name=self.building_id,
+                name=self.building_name,
                 year_of_construction=self.building["year_built"],
                 number_of_floors=self.building["num_stories"],
                 height_of_floors=self.building["floor_height"],
@@ -163,7 +165,7 @@ class Teaser(LoadBase):
         with fdopen(fh, 'w') as new_file:
             with open(f) as old_file:
                 for line in old_file:
-                    if "double Internals(8760, 19)" in line:
+                    if "double Internals(8760" in line:  # Finding the line, which may have one of several #s of columns
                         new_file.write("double Internals(8761, 4)\n")
                     elif line.startswith("3600\t"):
                         new_file.write(line.replace('3600\t', '0\t') + line)
@@ -254,6 +256,12 @@ class Teaser(LoadBase):
             # remove ReaderTMY3
             mofile.remove_component("Buildings.BoundaryConditions.WeatherData.ReaderTMY3", "weaDat")
 
+            # Remove `lat` from diffuse & direct solar gains (removed from MBL in version 9)
+            mofile.remove_component_argument("Buildings.BoundaryConditions.SolarIrradiation.DiffusePerez", "HDifTil", "lat")
+            mofile.remove_component_argument("Buildings.BoundaryConditions.SolarIrradiation.DiffusePerez", "HDifTilRoof", "lat")
+            mofile.remove_component_argument("Buildings.BoundaryConditions.SolarIrradiation.DirectTiltedSurface", "HDirTil", "lat")
+            mofile.remove_component_argument("Buildings.BoundaryConditions.SolarIrradiation.DirectTiltedSurface", "HDirTilRoof", "lat")
+
             # updating path to internal loads
             for s in string_replace_list:
                 new_file_path = s[1]
@@ -363,8 +371,8 @@ class Teaser(LoadBase):
             mofile.remove_connect('weaDat.weaBus', 'weaBus')
 
             # add new port connections
-            rc_order = self.system_parameters.get_param(
-                "buildings.default.load_model_parameters.rc.order", default=2
+            rc_order = self.system_parameters.get_param_by_building_id(
+                self.building_id, "load_model_parameters.rc.order", default=2
             )
             thermal_zone_name = None
             thermal_zone_type = None
@@ -481,7 +489,7 @@ class Teaser(LoadBase):
                     index_identifier="i",
                     expression_raw="1:nPorts",
                     loop_body_raw_list=[
-                        "connect(ports[i], thermalZoneFourElements.ports[i])",
+                        f"connect(ports[i], {thermal_zone_name}.ports[i])",
                         "\tannotation (Line(",
                         "\tpoints={{-18,-102},{-18,-84},{83,-84},{83,-1.95}},",
                         "\tcolor={0,127,255},",
@@ -489,6 +497,13 @@ class Teaser(LoadBase):
                     ],
                 )
 
+                # Fix the thermalZone medium model
+                mofile.overwrite_component_redeclaration(
+                    f"Buildings.ThermalZones.ReducedOrder.RC.{thermal_zone_type}",
+                    thermal_zone_name,
+                    "Medium = Buildings.Media.Air"
+                )
+
             # change the name of the modelica model to remove the building id, update in package too!
             original_model_name = mofile.get_name()
             new_model_name = original_model_name.split("_")[1]
@@ -518,10 +533,16 @@ class Teaser(LoadBase):
                 "placement": f"{{{{{-160 + index * 40},-20}},{{{-140 + index * 40},0}}}}"
             })
 
+        # Handle setting nominal load for IT room zone
+        nom_cool_flow = np.array([-10000] * len(zone_list))
+        for i, dic in enumerate(zone_list):
+            if dic["instance_name"] == "ict":
+                nom_cool_flow[i - 1] = -50000  # Need to offset for different indexing
+        nom_heat_flow = np.array([10000] * len(zone_list))
         building_template_data = {
             "thermal_zones": zone_list,
-            "nominal_heat_flow": [10000] * len(zone_list),
-            "nominal_cool_flow": [-10000] * len(zone_list),
+            "nominal_heat_flow": str(repr(nom_heat_flow))[1:-1].replace("[", "{").replace("]", "}").split("rray(", 1)[-1],
+            "nominal_cool_flow": str(repr(nom_cool_flow))[1:-1].replace("[", "{").replace("]", "}").split("rray(", 1)[-1],
             "load_resources_path": b_modelica_path.resources_relative_dir,
             "mos_weather": {
                 "mos_weather_filename": mos_weather_filename,
@@ -529,25 +550,38 @@ class Teaser(LoadBase):
                 "path": os.path.dirname(mos_weather_filename),
             },
             "nominal_values": {
-                # Adding 273.15 to convert from C to K (for absolute temps, not relative temps)
-                "chw_supply_temp": self.system_parameters.get_param_by_building_id(
+                "chw_supply_temp": convert_c_to_k(self.system_parameters.get_param_by_building_id(
                     self.building_id, "load_model_parameters.rc.temp_chw_supply"
-                ) + 273.15,
-                "chw_return_temp": self.system_parameters.get_param_by_building_id(
+                )),
+                "chw_return_temp": convert_c_to_k(self.system_parameters.get_param_by_building_id(
                     self.building_id, "load_model_parameters.rc.temp_chw_return"
-                ) + 273.15,
-                "hhw_supply_temp": self.system_parameters.get_param_by_building_id(
+                )),
+                "hhw_supply_temp": convert_c_to_k(self.system_parameters.get_param_by_building_id(
                     self.building_id, "load_model_parameters.rc.temp_hw_supply"
-                ) + 273.15,
-                "hhw_return_temp": self.system_parameters.get_param_by_building_id(
+                )),
+                "hhw_return_temp": convert_c_to_k(self.system_parameters.get_param_by_building_id(
                     self.building_id, "load_model_parameters.rc.temp_hw_return"
-                ) + 273.15,
-                "temp_setpoint_heating": self.system_parameters.get_param_by_building_id(
+                )),
+                "temp_setpoint_heating": convert_c_to_k(self.system_parameters.get_param_by_building_id(
                     self.building_id, "load_model_parameters.rc.temp_setpoint_heating"
-                ) + 273.15,
-                "temp_setpoint_cooling": self.system_parameters.get_param_by_building_id(
+                )),
+                "temp_setpoint_cooling": convert_c_to_k(self.system_parameters.get_param_by_building_id(
                     self.building_id, "load_model_parameters.rc.temp_setpoint_cooling"
-                ) + 273.15
+                )),
+                # FIXME: pick up default value from schema if not specified in system_parameters,
+                # FYI: Modelica insists on booleans being lowercase, so we need to explicitly set "true" and "false"
+                "has_liquid_heating": "true" if self.system_parameters.get_param_by_building_id(
+                    self.building_id, "load_model_parameters.rc.has_liquid_heating",
+                ) else "false",
+                "has_liquid_cooling": "true" if self.system_parameters.get_param_by_building_id(
+                    self.building_id, "load_model_parameters.rc.has_liquid_cooling",
+                ) else "false",
+                "has_electric_heating": "true" if self.system_parameters.get_param_by_building_id(
+                    self.building_id, "load_model_parameters.rc.has_electric_heating",
+                ) else "false",
+                "has_electric_cooling": "true" if self.system_parameters.get_param_by_building_id(
+                    self.building_id, "load_model_parameters.rc.has_electric_cooling",
+                ) else "false",
             }
         }
 
@@ -629,10 +663,10 @@ class Teaser(LoadBase):
 
         # now create the Package level package. This really needs to happen at the GeoJSON to modelica stage, but
         # do it here for now to aid in testing.
-        pp = PackageParser.new_from_template(
-            scaffold.project_path, scaffold.project_name, ["Loads"]
-        )
-        pp.save()
+        package = PackageParser(scaffold.project_path)
+        if 'Loads' not in package.order:
+            package.add_model('Loads')
+            package.save()
 
     def get_modelica_type(self, scaffold):
         return f'{scaffold.project_name}.Loads.{self.building_name}.building'
