@@ -1,6 +1,6 @@
 """
 ****************************************************************************************************
-:copyright (c) 2019-2021 URBANopt, Alliance for Sustainable Energy, LLC, and other contributors.
+:copyright (c) 2019-2022, Alliance for Sustainable Energy, LLC, and other contributors.
 
 All rights reserved.
 
@@ -346,7 +346,7 @@ class InputParser(object):
     def add_parameter(self, var_type, var_name, value, description):
         """Add a new parameter. Will be prepended to the top of the models list
 
-        :param var_type: string, type of Modelica variable, Real, Integer, String, Modelica.SIunits.Area, etc.
+        :param var_type: string, type of Modelica variable, Real, Integer, String, Modelica.Units.SI.Area, etc.
         :param var_name: string, name of the variable. Note that this does not check for conflicts.
         :param value: variant, value to set the variable name to.
         :param description: string, description of the parameter
