@@ -1,6 +1,6 @@
 """
 ****************************************************************************************************
-:copyright (c) 2019-2021 URBANopt, Alliance for Sustainable Energy, LLC, and other contributors.
+:copyright (c) 2019-2022, Alliance for Sustainable Energy, LLC, and other contributors.
 
 All rights reserved.
 
@@ -37,28 +37,12 @@ OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 """
 
 from pathlib import Path
+from shutil import rmtree
 
 import click
 from geojson_modelica_translator.geojson_modelica_translator import (
     GeoJsonModelicaTranslator
 )
-from geojson_modelica_translator.model_connectors.couplings import (
-    Coupling,
-    CouplingGraph
-)
-from geojson_modelica_translator.model_connectors.districts import District
-from geojson_modelica_translator.model_connectors.energy_transfer_systems import (
-    CoolingIndirect,
-    HeatingIndirect
-)
-from geojson_modelica_translator.model_connectors.load_connectors import (
-    TimeSeries
-)
-from geojson_modelica_translator.model_connectors.networks import Network2Pipe
-from geojson_modelica_translator.model_connectors.plants import (
-    CoolingPlant,
-    HeatingPlant
-)
 from geojson_modelica_translator.modelica.modelica_runner import ModelicaRunner
 from geojson_modelica_translator.system_parameters.system_parameters import (
     SystemParameters
@@ -97,13 +81,20 @@ def cli():
     help="Delete and replace any existing file of the same name & location",
     default=False
 )
-def build_sys_param(model_type, sys_param_filename, scenario_file, feature_file, overwrite):
+@click.option(
+    '-m',
+    '--microgrid',
+    is_flag=True,
+    help="If specified, microgrid inputs will be added to system parameters file",
+    default=False
+)
+def build_sys_param(model_type: str, sys_param_filename: Path, scenario_file: Path, feature_file: Path, overwrite: bool, microgrid: bool):
     """
     Create system parameters file using uo_sdk output
 
     SYS_PARAM_FILENAME: Path/name to sys-param file be created. Be sure to include the ".json" suffix.
 
-    SCENARIO_FILE: Path to sdk scenario folder with OpenStudio results.
+    SCENARIO_FILE: Path to sdk scenario file.
 
     FEATURE_FILE: Path to sdk json feature file with data about the buildings.
 
@@ -123,18 +114,20 @@ def build_sys_param(model_type, sys_param_filename, scenario_file, feature_file,
     scenario_name = Path(scenario_file).stem
     scenario_dir = Path(scenario_file).parent / 'run' / scenario_name
 
-    SystemParameters.csv_to_sys_param(
+    sp = SystemParameters()
+    sp.csv_to_sys_param(
         model_type=model_type,
         sys_param_filename=Path(sys_param_filename),
         scenario_dir=Path(scenario_dir),
         feature_file=Path(feature_file),
-        overwrite=overwrite
+        overwrite=overwrite,
+        microgrid=microgrid
     )
 
     if Path(sys_param_filename).exists():
         print(f"\nSystem parameters file {sys_param_filename} successfully created.")
     else:
-        raise Exception(f"{sys_param_filename} failed. Please check your inputs and try again.")
+        raise SystemExit(f"{sys_param_filename} failed. Please check your inputs and try again.")
 
 
 @cli.command(short_help="Create Modelica model")
@@ -147,103 +140,52 @@ def build_sys_param(model_type, sys_param_filename, scenario_file, feature_file,
     type=click.Path(exists=True, file_okay=True, dir_okay=False),
 )
 @click.argument(
-    "project_name",
+    "project_path",
     default="model_from_sdk",
     type=click.Path(exists=False, file_okay=False, dir_okay=True),
 )
-@click.argument(
-    "model_type",
-    default='time_series',
+@click.option(
+    '-o',
+    '--overwrite',
+    is_flag=True,
+    help="Delete and replace any existing folder of the same name & location",
+    default=False
 )
-def create_model(model_type, sys_param_file, geojson_feature_file, project_name):
+def create_model(sys_param_file: Path, geojson_feature_file: Path, project_path: Path, overwrite: bool):
     """Build Modelica model from user data
 
     SYS_PARAM_FILE: Path/name to sys-param file, possibly created with this CLI.
 
     GEOJSON_FEATURE_FILE: Path to sdk json feature file with data about the buildings.
 
-    PROJECT_NAME: Path for Modelica project directory created with this command
-
-    \b
-    MODEL_TYPE: selection for which kind of simulation this model will support.
-        Valid choices for MODEL_TYPE: "time_series"
-        Default: "time_series"
+    PROJECT_PATH: Path for Modelica project directory created with this command
 
     \f
     :param model_type: String, type of model to create
     :param sys_param_file: Path, location and name of file created with this cli
     :param geojson_feature_file: Path, location and name of sdk feature_file
+    :param project_path: Path, location and name of Modelica model dir to be created
+    :param overwrite: Boolean, flag to overwrite an existing file of the same name/location
     """
+    project_path = Path(project_path)
+    if project_path.exists():
+        if overwrite:
+            rmtree(project_path, ignore_errors=True)
+        else:
+            raise SystemExit(f"Output dir '{project_path}' already exists and overwrite flag is not given")
+    if len(project_path.name.split()) > 1:  # Modelica can't handle spaces in project name
+        raise SystemExit(
+            f"\n'{project_path}' failed. Modelica does not support spaces in project names or paths. "
+            "Please choose a different 'project_path'")
 
-    gj = GeoJsonModelicaTranslator.from_geojson(geojson_feature_file)
-    sys_params = SystemParameters(sys_param_file)
-    modelica_project_name = Path(project_name).stem
-    project_run_dir = Path(project_name).parent
-
-    # create cooling network and plant
-    # TODO: Enable selecting different plant models in sys-param file, kinda like this concept
-    # if sys_params.get_param("$.district_system.default"):
-    #     cooling_plant = CoolingPlant(sys_params)
-    # elif sys_params.get_param("$.district_system.osu"):
-    #     cooling_plant = CoolingPlantOSU(sys_params)
-    # else:
-    #     raise SystemExit(f"Cooling plant not defined")
-    cooling_network = Network2Pipe(sys_params)
-    cooling_plant = CoolingPlant(sys_params)
-
-    # create heating network and plant
-    heating_network = Network2Pipe(sys_params)
-    heating_plant = HeatingPlant(sys_params)
-
-    # create our load/ets/stubs
-    # store all couplings to construct the District system
-    all_couplings = [
-        Coupling(cooling_network, cooling_plant),
-        Coupling(heating_network, heating_plant),
-    ]
-
-    # keep track of separate loads and etses
-    loads = []
-    heat_etses = []
-    cool_etses = []
-    # Simalar to load_base.py, only check buildings that are in the sys-param file
-    for building in sys_params.get_default('$.buildings.custom[*].geojson_id', []):
-        for geojson_load in gj.json_loads:
-            # Read load & ets data from user-supplied files, build objects from them
-            if geojson_load.feature.properties["id"] == building:
-                if model_type == "time_series":
-                    time_series_load = TimeSeries(sys_params, geojson_load)
-                    loads.append(time_series_load)
-                else:
-                    raise Exception(f"Model type: '{model_type}' is not supported at this time. \
-'time_series' is the only valid model_type.")
-                geojson_load_id = geojson_load.feature.properties["id"]
-
-                cooling_indirect = CoolingIndirect(sys_params, geojson_load_id)
-                cool_etses.append(cooling_indirect)
-                all_couplings.append(Coupling(time_series_load, cooling_indirect))
-                all_couplings.append(Coupling(cooling_indirect, cooling_network))
-
-                heating_indirect = HeatingIndirect(sys_params, geojson_load_id)
-                heat_etses.append(heating_indirect)
-                all_couplings.append(Coupling(time_series_load, heating_indirect))
-                all_couplings.append(Coupling(heating_indirect, heating_network))
-
-    # create the couplings and graph
-    graph = CouplingGraph(all_couplings)
-
-    district = District(
-        root_dir=project_run_dir,
-        project_name=modelica_project_name,
-        system_parameters=sys_params,
-        coupling_graph=graph
+    gmt = GeoJsonModelicaTranslator(
+        geojson_feature_file,
+        sys_param_file,
+        project_path.parent,
+        project_path.name
     )
-    district.to_modelica()
 
-    if (Path(project_name) / 'Districts' / 'DistrictEnergySystem.mo').exists():
-        print(f"\nModelica model {modelica_project_name} successfully created in {project_run_dir}.")
-    else:
-        raise Exception(f"{modelica_project_name} failed. Please check your inputs and try again.")
+    gmt.to_modelica()
 
 
 @cli.command(short_help="Run Modelica model")
@@ -253,7 +195,7 @@ def create_model(model_type, sys_param_file, geojson_feature_file, project_name)
     required=True,
     type=click.Path(exists=True, file_okay=False, dir_okay=True),
 )
-def run_model(modelica_project):
+def run_model(modelica_project: Path):
     """
     \b
     Run the Modelica project in a docker-based environment.
@@ -271,6 +213,11 @@ def run_model(modelica_project):
     project_name = run_path.stem
     file_to_run = run_path / 'Districts' / 'DistrictEnergySystem.mo'
 
+    if len(str(run_path).split()) > 1:  # Modelica can't handle spaces in project name or path
+        raise SystemExit(
+            f"\n'{run_path}' failed. Modelica does not support spaces in project names or paths. "
+            "Please update your directory tree to not include spaces in any name")
+
     # setup modelica runner
     mr = ModelicaRunner()
     mr.run_in_docker(file_to_run, run_path=run_path.parent, project_name=project_name)
@@ -278,4 +225,4 @@ def run_model(modelica_project):
     if (run_path.parent / f'{project_name}_results' / f'{project_name}_Districts_DistrictEnergySystem_result.mat').exists():
         print(f"\nModelica model {project_name} ran successfully")
     else:
-        raise Exception(f"{project_name} failed. Please check your inputs and try again.")
+        raise SystemExit(f"\n{project_name} failed. Check the error log at {project_name}_results/stdout.log for more info.")
